slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPSetProblemType

Specifies the type of the nonlinear eigenvalue problem.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPSetProblemType(NEP nep,NEPProblemType type)

Logically Collective on nep

### Input Parameters

| nep | - the nonlinear eigensolver context
| type | - a known type of nonlinear eigenvalue problem

### Options Database Keys

| -nep_general | - general problem with no particular structure
| -nep_rational | - a rational eigenvalue problem defined in split form with all f_i rational

### Notes

Allowed values for the problem type are general (NEP_GENERAL), and rational (NEP_RATIONAL).

This function is used to provide a hint to the NEP solver to exploit certain properties of the nonlinear eigenproblem. This hint may be used or not, depending on the solver. By default, no particular structure is assumed.

### See Also

NEPSetType(), NEPGetProblemType(), NEPProblemType

### Level

intermediate

### Location

src/nep/interface/nepopts.c

### Examples

src/nep/tutorials/ex22f90.F90.html
src/nep/tutorials/ex42.c.html
src/nep/tutorials/nlevp/loaded_string.c.html
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages